@@ -8,9 +8,11 @@
 #'  - [teow]
 #'
 #' @name ecoregion
-#' @docType data
 #' @keywords indicator
-#' @format A tibble with a column for name of the ecoregions and corresponding area (in ha).
+#' @returns A function that returns a tibble with a column for name of the
+#'   ecoregions and corresponding area (in ha).
+#' @include register.R
+#' @export
 #' @examples
 #' \dontshow{
 #' mapme.biodiversity:::.copy_resource_dir(file.path(tempdir(), "mapme-data"))
@@ -22,72 +24,58 @@
 #' outdir <- file.path(tempdir(), "mapme-data")
 #' dir.create(outdir, showWarnings = FALSE)
 #'
+#' mapme_options(
+#'   outdir = outdir,
+#'   verbose = FALSE
+#' )
+#'
 #' aoi <- system.file("extdata", "sierra_de_neiba_478140_2.gpkg",
 #'   package = "mapme.biodiversity"
 #' ) %>%
 #'   read_sf() %>%
-#'   init_portfolio(
-#'     years = 2001,
-#'     outdir = outdir,
-#'     tmpdir = tempdir(),
-#'     verbose = FALSE
-#'   ) %>%
-#'   get_resources("teow") %>%
-#'   calc_indicators("ecoregion") %>%
+#'   get_resources(get_teow()) %>%
+#'   calc_indicators(calc_ecoregion()) %>%
 #'   tidyr::unnest(ecoregion)
 #'
 #' aoi
 #' }
-NULL
+calc_ecoregion <- function() {
+  function(x,
+           teow = NULL,
+           name = "ecoregion",
+           mode = "asset",
+           verbose = mapme_options()[["verbose"]]) {
+    ECO_NAME <- NULL
+    new_area <- NULL
+    ecoregions <- NULL
+    area <- NULL
 
-#' Calculate terrestrial ecoregions statistics (TEOW) based on WWF
-#'
-#' Considering global TEOW polygons from WWF for the year 2001 users can
-#' retrieve the name of the ecoregions and compute the corresponding area
-#' of the particular ecoregions for their polygons.
-#'
-#' @param x A single polygon for which to calculate the ecoregion statistics
-#' @param teow The teow vector resource (TEOW - WWF)
-#' @param verbose A directory where intermediate files are written to.
-#' @param todisk Logical indicating whether or not temporary vector files shall
-#'   be written to disk
-#' @param ... additional arguments
-#' @return A tibble
-#' @keywords internal
-#' @include register.R
-#' @noRd
-.calc_ecoregion <- function(x,
-                            teow,
-                            verbose = TRUE,
-                            ...) {
-  ECO_NAME <- NULL
-  new_area <- NULL
-  ecoregions <- NULL
-  area <- NULL
+    if (nrow(teow[[1]]) == 0) {
+      return(NA)
+    }
 
-  if (nrow(teow[[1]]) == 0) {
-    return(NA)
+    merged <- .comp_teow(
+      x = x,
+      teow = teow,
+      verbose = verbose
+    )
+
+    if (nrow(merged) == 0) {
+      return(NA)
+    }
+
+    out <- merged %>%
+      dplyr::select(ECO_NAME, new_area)
+
+    out_tibble <- tibble(
+      ecoregions = out[[1]],
+      area = out[[2]]
+    )
+
+    out_tibble %>%
+      dplyr::group_by(ecoregions) %>%
+      dplyr::summarise(area = sum(as.numeric(area)))
   }
-
-  merged <- .comp_teow(
-    x = x,
-    teow = teow,
-    verbose = verbose)
-
-  if (nrow(merged) == 0) {
-    return(NA)
-  }
-
-  out <- merged %>%
-    dplyr::select(ECO_NAME, new_area)
-
-  out_tibble <- tibble(
-    ecoregions = out[[1]],
-    area = out[[2]])
-
-  out_tibble %>%
-    dplyr::group_by(ecoregions) %>%
-    dplyr::summarise(area = sum(as.numeric(area)))
 }
 
 #' Helper function to intersect polygons and add biome names
@@ -102,7 +90,9 @@ NULL
                        teow,
                        verbose = TRUE,
                        ...) {
-  intersected <- suppressWarnings(st_intersection(x, teow[[1]]))
+  teow <- teow[[1]]
+  teow <- st_make_valid(teow)
+  intersected <- suppressWarnings(st_intersection(x, teow))
   biome_and_name <- data.frame(
     BIOME = c(1:14, 98, 99),
     BIOME_NAME = c(
@@ -135,8 +125,6 @@ NULL
 
 register_indicator(
   name = "ecoregion",
-  resources = list(teow = "vector"),
-  fun = .calc_ecoregion,
-  arguments = list(),
-  processing_mode = "asset"
+  description = "Areal statstics of ecoregions based on TEOW",
+  resources = "teow"
 )
