@@ -7,73 +7,60 @@
 #' discrete classifications from ESA.
 #'
 #' @name esalandcover
-#' @docType data
+#' @param years A numeric vector indicating the years for which to make the
+#'   resource available.
 #' @keywords resource
-#' @format A global tiled raster resource available for years 2015 to 2019.
+#' @returns  A function that returns a character of file paths.
 #' @references © European Union, Copernicus Land Monitoring Service (year),
 #' European Environment Agency (EEA)", f.ex. in 2018: “© European Union,
 #' Copernicus Land Monitoring Service 2018, European Environment Agency (EEA)
 #' @source \url{https://lcviewer.vito.be/download}
-NULL
-
-
-#' Downloads Copernicus Global Land Cover layer
-#'
-#' @param x An sf object returned by init_portfolio
-#' @param rundir A directory where intermediate files are written to.
-#' @param verbose Logical controlling verbosity.
-#' @keywords internal
 #' @include register.R
-#' @noRd
-.get_esalandcover <- function(x,
-                              rundir = tempdir(),
-                              verbose = TRUE) {
-  target_years <- attributes(x)$years
-  available_years <- c(2015:2019)
-  target_years <- .check_available_years(
-    target_years, available_years, "esalandcover"
-  )
+#' @export
+get_esalandcover <- function(years = 2015:2019) {
+  years <- check_available_years(years, c(2015:2019), "esalandcover")
 
-  # make the ESA grid and construct urls for intersecting tiles
-  grid_esa <- .make_global_grid(
-    xmin = -180, xmax = 180, dx = 20,
-    ymin = -60, ymax = 80, dy = 20
-  )
-  tile_ids <- unique(unlist(st_intersects(x, grid_esa)))
-  if (length(tile_ids) == 0) {
-    stop(paste("The extent of the portfolio does not ",
-      "intersect with the Land Cover grid.",
-      sep = ""
-    ))
-  }
-  # create all urls for target years and per tile
-  urls <- c()
-  for (i in tile_ids) {
-    tmp <- purrr::map_chr(target_years, .get_esa_url, tile = grid_esa[i, ])
-    urls <- c(urls, tmp)
-  }
-  # change filename structure
-  basenames <- basename(urls)
-  splitted <- strsplit(basenames, "-|_")
-  filenames <- purrr::map_chr(basenames, function(x) {
-    x <- strsplit(x, "-|_")[[1]]
-    paste0(x[1], "_", x[3], "_", x[5], "_", x[6], ".tif")
-  })
+  function(x,
+           name = "esalandcover",
+           type = "raster",
+           outdir = mapme_options()[["outdir"]],
+           verbose = mapme_options()[["verbose"]],
+           testing = mapme_options()[["testing"]]) {
+    # make the ESA grid and construct urls for intersecting tiles
+    grid_esa <- make_global_grid(
+      xmin = -180, xmax = 180, dx = 20,
+      ymin = -60, ymax = 80, dy = 20
+    )
+    tile_ids <- unique(unlist(st_intersects(x, grid_esa)))
+    if (length(tile_ids) == 0) {
+      stop(paste("The extent of the portfolio does not ",
+        "intersect with the Land Cover grid.",
+        sep = ""
+      ))
+    }
+    # create all urls for target years and per tile
+    urls <- c()
+    for (i in tile_ids) {
+      tmp <- purrr::map_chr(years, .get_esa_url, tile = grid_esa[i, ])
+      urls <- c(urls, tmp)
+    }
+    # change filename structure
+    basenames <- basename(urls)
+    splitted <- strsplit(basenames, "-|_")
+    filenames <- purrr::map_chr(basenames, function(x) {
+      x <- strsplit(x, "-|_")[[1]]
+      paste0(x[1], "_", x[3], "_", x[5], "_", x[6], ".tif")
+    })
 
-  if (attr(x, "testing")) {
-    return(basename(filenames))
-  }
+    if (testing) {
+      return(basename(filenames))
+    }
 
-  filenames <- file.path(rundir, basename(filenames))
-  aria_bin <- attributes(x)$aria_bin
-  filenames <- .download_or_skip(urls,
-    filenames,
-    verbose,
-    aria_bin = aria_bin,
-    check_existence = TRUE
-  )
-  # return all paths to the downloaded files
-  filenames
+    filenames <- file.path(outdir, basename(filenames))
+    filenames <- download_or_skip(urls, filenames, check_existence = TRUE)
+    # return all paths to the downloaded files
+    filenames
+  }
 }
 
 #' Helper function to create ESA land cover urls
@@ -133,8 +120,8 @@ NULL
 
 register_resource(
   name = "esalandcover",
-  type = "raster",
+  licence = "CC-BY 4.0",
+  description = "Copernicus Land Monitoring Service (CLMS) 100 meter land cover product",
   source = "https://registry.opendata.aws/esa-worldcover-vito/",
-  fun = .get_esalandcover,
-  arguments <- list()
+  type = "raster"
 )
