@@ -18,52 +18,44 @@
 #' emissions for areas where no data is available.
 #'
 #' @name gfw_emissions
-#' @docType data
 #' @keywords resource
-#' @format A global tiled raster resource available for all land areas.
+#' @returns A function that returns a character of file paths.
 #' @references Harris, N.L., Gibbs, D.A., Baccini, A. et al. Global maps of
 #' twenty-first century forest carbon fluxes. Nat. Clim. Chang. 11, 234–240
 #' (2021). https://doi.org/10.1038/s41558-020-00976-6
 #' @source \url{https://data.globalforestwatch.org/datasets/gfw::forest-greenhouse-gas-emissions/about}
-NULL
-
-
-#' Get greenhouse layer
-#'
-#' @param x An sf object returned by init_portfolio
-#' @param verbose Logical controlling verbosity.
-#' @param rundir A directory where intermediate files are written to.
-#' @keywords internal
 #' @include register.R
-#' @noRd
-.get_gfw_emissions <- function(x,
-                               verbose = TRUE,
-                               rundir = tempdir()) {
-  index_file <- system.file("extdata", "greenhouse_index.geosjon", package = "mapme.biodiversity")
-  spatialindex <- st_read(index_file, quiet = TRUE)
-  tile_ids <- unique(unlist(st_intersects(x, spatialindex)))
-  tile_ids <- spatialindex$tile_id[tile_ids]
-  urls <- as.character(
-    spatialindex$Mg_CO2e_px_download[spatialindex$tile_id %in% tile_ids]
-  )
-  filenames <- file.path(
-    rundir,
-    sprintf("gfw_forest_carbon_gross_emissions_Mg_CO2e_px_%s.tif", tile_ids)
-  )
-  if (attr(x, "testing")) {
-    return(basename(filenames))
+#' @export
+get_gfw_emissions <- function() {
+  function(x,
+           name = "gfw_emissions",
+           type = "raster",
+           outdir = mapme_options()[["outdir"]],
+           verbose = mapme_options()[["verbose"]],
+           testing = mapme_options()[["testing"]]) {
+    index_file <- system.file("extdata", "greenhouse_index.geosjon", package = "mapme.biodiversity")
+    spatialindex <- st_read(index_file, quiet = TRUE)
+    tile_ids <- unique(unlist(st_intersects(x, spatialindex)))
+    tile_ids <- spatialindex$tile_id[tile_ids]
+    urls <- as.character(
+      spatialindex$Mg_CO2e_px_download[spatialindex$tile_id %in% tile_ids]
+    )
+    filenames <- file.path(
+      outdir,
+      sprintf("gfw_forest_carbon_gross_emissions_Mg_CO2e_px_%s.tif", tile_ids)
+    )
+    if (mapme_options()[["testing"]]) {
+      return(basename(filenames))
+    }
+    filenames <- download_or_skip(urls, filenames, check_existence = FALSE)
+    filenames
   }
-  aria_bin <- attributes(x)$aria_bin
-  .download_or_skip(urls, filenames, verbose, check_existence = FALSE, aria_bin = aria_bin)
-  # return all paths to the downloaded files
-  filenames
 }
 
-
 register_resource(
   name = "gfw_emissions",
-  type = "raster",
+  description = "Global Forest Watch - CO2 Emssions caused by forest cover loss",
+  licence = "CC-BY 4.0",
   source = "https://data.globalforestwatch.org/datasets/gfw::forest-greenhouse-gas-emissions/about",
-  fun = .get_gfw_emissions,
-  arguments <- list()
+  type = "raster"
 )
