@@ -9,57 +9,40 @@
 #'
 #'
 #' @name gmw
+#' @param years A numeric vector of the years for which to make GMW available.
 #' @docType data
 #' @keywords resource
-#' @format Global mangrove extent polygon available for years 1996, 2007-2010,
-#'   and 2015-2020.
+#' @returns A function that returns a character of file paths.
 #' @references Bunting P., Rosenqvist A., Lucas R., Rebelo L-M., Hilarides L.,
 #' Thomas N., Hardy A., Itoh T., Shimada M. and Finlayson C.M. (2018). The Global
 #' Mangrove Watch – a New 2010 Global Baseline of Mangrove Extent. Remote Sensing
 #' 10(10): 1669. doi:10.3390/rs10101669.
 #' @source \url{https://data.unep-wcmc.org/datasets/45}
-NULL
-
-
-#' Downloads Global Mangrove Extent Polygon
-#'
-#' @param x An sf object returned by init_portfolio
-#' @param rundir A directory where intermediate files are written to.
-#' @param verbose Logical controlling verbosity.
-#' @importFrom utils unzip
-#' @keywords internal
 #' @include register.R
-#' @noRd
-.get_gmw <- function(x,
-                     rundir = tempdir(),
-                     verbose = TRUE) {
-  target_years <- attributes(x)$years
-  available_years <- c(1996, 2007:2010, 2015:2020)
-  target_years <- .check_available_years(
-    target_years, available_years, "mangroveextent"
-  )
-  urls <- unlist(sapply(target_years, function(year) .get_mangrove_url(year)))
-  filenames <- file.path(
-    rundir,
-    basename(paste0("gmw-extent_", target_years, ".zip"))
-  )
-  if (attr(x, "testing")) {
-    return(basename(filenames))
+#' @export
+get_gmw <- function(years = c(1996, 2007:2010, 2015:2020)) {
+  avail_years <- c(1996, 2007:2010, 2015:2020)
+  years <- check_available_years(years, avail_years, "gmw")
+
+  function(x,
+           name = "gmw",
+           type = "vector",
+           outdir = mapme_options()[["outdir"]],
+           verbose = mapme_options()[["verbose"]],
+           testing = mapme_options()[["testing"]]) {
+    urls <- unlist(sapply(years, function(year) .get_mangrove_url(year)))
+    filenames <- file.path(outdir, basename(paste0("gmw-extent_", years, ".zip")))
+    if (testing) {
+      return(basename(filenames))
+    }
+    filenames <- download_or_skip(urls, filenames, check_existence = FALSE)
+    if (verbose) {
+      message("Translating shapefiles to GeoPackages. This may take a while....")
+    }
+    sapply(filenames, function(zip) .unzip_mangrove(zip, outdir))
+    out <- list.files(outdir, full.names = T, pattern = ".gpkg")
+    grep(paste(years, collapse = "|"), out, value = TRUE)
   }
-
-  if (any(file.exists(filenames))) {
-    message("Skipping existing files in output directory.")
-  }
-  # start download in a temporal directory within tmpdir
-  aria_bin <- attributes(x)$aria_bin
-  .download_or_skip(urls, filenames, verbose, aria_bin = aria_bin)
-
-  # unzip and convert shp to gpkg
-  message("Translating shapefiles to GeoPackages. This may take a while....")
-  sapply(filenames, function(zip) .unzip_mangrove(zip, rundir))
-
-  # return paths to the gpkg
-  list.files(rundir, full.names = T, pattern = ".gpkg")
 }
 
 
@@ -67,35 +50,35 @@ NULL
 #'
 #'
 #' @param zip_files A character vector with potentially multiple zip files
-#' @param rundir The directory to where the files are unzipped
+#' @param dir The directory to where the files are unzipped
 #'
 #' @return Nothing.
 #' @keywords internal
 #' @noRd
-.unzip_mangrove <- function(zip, rundir) {
+.unzip_mangrove <- function(zip, dir) {
   bn <- basename(zip)
   year <- gsub(".*?([0-9]+).*", "\\1", bn)
-  gpkg <- file.path(rundir, paste0("gmw-extent_", year, ".gpkg"))
+  gpkg <- file.path(dir, paste0("gmw-extent_", year, ".gpkg"))
   if (file.exists(gpkg)) {
     return(gpkg)
   }
   utils::unzip(
     zipfile = file.path(
-      rundir,
+      dir,
       basename(paste0("gmw-extent_", year, ".zip"))
     ),
-    exdir = rundir
+    exdir = dir
   )
 
   # Source data from 2018 doesn't correspond to the pattern for other years.
   # We need to create an exception for it.
   if (year == 2018) {
     shp <- file.path(
-      rundir,
+      dir,
       paste0("GMW_v3_2018/00_Data/gmw_v3_", year, ".shp")
     )
   } else {
-    shp <- file.path(rundir, paste0("gmw_v3_", year, "_vec.shp"))
+    shp <- file.path(dir, paste0("gmw_v3_", year, "_vec.shp"))
   }
 
   gdal_utils(
@@ -103,7 +86,7 @@ NULL
     options = c("-t_srs", "EPSG:4326")
   )
 
-  d_files <- list.files(rundir, full.names = T)
+  d_files <- list.files(dir, full.names = T)
   unlink(grep("gmw-extent*", d_files, value = T, invert = T),
     recursive = T, force = T
   )
@@ -134,8 +117,8 @@ NULL
 
 register_resource(
   name = "gmw",
-  type = "vector",
+  description = "Global Mangrove Watch - Vector data of mangrove extent",
+  licence = "CC BY 4.0",
   source = "https://data.unep-wcmc.org/datasets/45",
-  fun = .get_gmw,
-  arguments <- list()
+  type = "vector"
 )
