@@ -8,7 +8,8 @@ test_that("active fire count works", {
     package = "mapme.biodiversity"
   ), pattern = ".gpkg$", full.names = TRUE)
   nasa_firms <- read_sf(source)
-  result <- .calc_active_fire_counts(shp, list(nasa_firms))
+  afc <- calc_active_fire_counts()
+  result <- afc(shp, list(nasa_firms))
   expect_equal(
     names(result),
     c("instrument", "year", "active_fire_counts")
@@ -29,7 +30,7 @@ test_that("active fire count works", {
   # test that it works with both VIRRS and MODIS sensors
   nasa_firms2 <- list(nasa_firms, nasa_firms)
   nasa_firms2[[2]]$instrument <- "MODIS"
-  result2 <- .calc_active_fire_counts(shp, nasa_firms2)
+  result2 <- afc(shp, nasa_firms2)
   expect_equal(
     result2$instrument,
     c("MODIS", "VIIRS")
