@@ -8,7 +8,8 @@ test_that("active fire properties works", {
     package = "mapme.biodiversity"
   ), pattern = ".gpkg$", full.names = TRUE)
   nasa_firms <- read_sf(source)
-  result <- .calc_active_fire_properties(shp, list(nasa_firms))
+  afp <- calc_active_fire_properties()
+  result <- afp(shp, list(nasa_firms))
   expect_equal(
     nrow(result),
     21
@@ -17,7 +18,7 @@ test_that("active fire properties works", {
   nasa_firms2 <- list(nasa_firms, nasa_firms)
   nasa_firms2[[2]]$instrument <- "MODIS"
   nasa_firms2[[2]]$confidence <- 1:nrow(nasa_firms2[[2]])
-  result2 <- .calc_active_fire_properties(shp, nasa_firms2)
+  result2 <- afp(shp, nasa_firms2)
   expect_equal(
     nrow(result2),
     42
