@@ -1,3 +1,8 @@
+test_that(".get_gfw_tile_id works", {
+  gfw_grid <- make_global_grid()
+  expect_equal(.get_gfw_tile_id(gfw_grid[100, ]), "20S_110E")
+})
+
 test_that(".get_gfw_treecover works", {
   skip_on_cran()
   aoi <- read_sf(
@@ -14,35 +19,18 @@ test_that(".get_gfw_treecover works", {
   outdir <- file.path(tempdir(), "mapme.biodiversity", "res")
   tmpdir <- tempdir()
 
-  portfolio <- init_portfolio(aoi,
-    years = 2000:2020,
+  mapme_options(
     outdir = outdir,
     tmpdir = tmpdir,
-    verbose = TRUE
-  )
-  # Add testing attribute in order to skip downloads
-  attributes(portfolio)$testing <- TRUE
-
-  expect_error(
-    .get_gfw_treecover(portfolio, vers_treecover = "not-available"),
+    verbose = TRUE,
+    testing = TRUE
   )
 
-  expect_equal(
-    .get_gfw_treecover(portfolio, vers_treecover = "GFC-2020-v1.8"),
-    "Hansen_GFC-2020-v1.8_treecover2000_20N_080W.tif"
-  )
+  expect_error(get_gfw_treecover(version = "not-available"))
+  gt <- get_gfw_treecover(version = "GFC-2020-v1.8")
+  expect_equal(gt(aoi), "Hansen_GFC-2020-v1.8_treecover2000_20N_080W.tif")
 
   # adds test to check for multiple polygons in the same tile
   splitted_aoi <- st_as_sf(st_make_grid(aoi, n = 2))
-  portfolio <- init_portfolio(splitted_aoi,
-    years = 2000:2020,
-    outdir = outdir,
-    tmpdir = tmpdir,
-    verbose = TRUE
-  )
-  attributes(portfolio)$testing <- TRUE
-  expect_equal(
-    .get_gfw_treecover(portfolio, vers_treecover = "GFC-2020-v1.8"),
-    "Hansen_GFC-2020-v1.8_treecover2000_20N_080W.tif"
-  )
+  expect_equal(gt(splitted_aoi), "Hansen_GFC-2020-v1.8_treecover2000_20N_080W.tif")
 })
